body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;margin:0}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}table{background-color:#fff;border-radius:4px;font-family:sans-serif,Calibri,Gill Sans,Gill Sans MT,Trebuchet MS}table,td,th{border-collapse:collapse;font-size:12px;min-width:40px;table-layout:fixed}table th{background-color:#f4f4f4;font-size:12px;font-weight:600;font-weight:700;height:51px}td,th{min-height:39px;overflow-wrap:break-word;padding:5px;text-align:center;width:45px}td{border-bottom:1.5px solid #e6ecf0;font-size:11px}.input-field{border-radius:7px;cursor:pointer;font-size:12px;height:65%;text-align:center;width:100%}.input-field:active,.input-field:focus{background-color:#f4f4f4;border:1px solid #dcdada}.category_label{font-weight:700;width:80px}.total_label{background-color:#f0f5f8}.last_row{background-color:#c2d5fe}
/*# sourceMappingURL=main.a88d3fd1.css.map*/